@@ -318,7 +318,7 @@ class K3SController:
         
     @exception_class_dec(max_try=1)
     def create_job(self, cluster_name:str, job_setting:JobSettingDO, timeout=10):
-        data = json.dumps(job_setting.to_json())
+        data = json.dumps(job_setting.dict())
         response=requests.post(
             f'{self.url}/job/cluster_name/{cluster_name}', 
             headers=self.header, data=data, timeout=timeout)
