@@ -277,87 +277,69 @@ class PodContainerDO(BaseDO):
     container_info: str
     _life_time: int=5
 
-@dataclass
-class KeyToPathDO(BaseDO):
+class KeyToPathDO(BaseModel):
     key: str
     path: str
     mode: Optional[int]=None
 
-# @dataclass
-# class PodSecurityContextDO(BaseDO):
-#     run_as_user: Optional[int]=None
-#     run_as_group: Optional[int]=None
-#     run_as_non_root: Optional[bool]=None
-
-@dataclass
-class EnvVarSourceDO(BaseDO):
+class EnvVarSourceDO(BaseModel):
     env_var_source_type: str
     key: str
     name: str
     optional: Optional[bool]=None
 
-@dataclass
-class EnvVarDO(BaseDO):
+class EnvVarDO(BaseModel):
     name: str
     value_from: Optional[EnvVarSourceDO] = None
     value: Optional[str]=None
 
-@dataclass
-class VolumeSourceDO(BaseDO):
+class VolumeSourceDO(BaseModel):
     name: str  
     volume_type: str
     default_mode: Optional[int] = None
     items: Optional[List[KeyToPathDO]] = None
     optional: Optional[bool] = None
 
-@dataclass
-class PersistentVolumeClaimeVolumeSourceDO(BaseDO):
+class PersistentVolumeClaimeVolumeSourceDO(BaseModel):
     claim_name: str
     read_only: Optional[bool] = None
 
-@dataclass
-class VolumeSettingDO(BaseDO):
+class VolumeSettingDO(BaseModel):
     volume_name: str
     empty_dir: Optional[bool] = None
     config_map: Optional[VolumeSourceDO] = None
     secret: Optional[VolumeSourceDO] = None
     persistent_volume_claim: Optional[PersistentVolumeClaimeVolumeSourceDO] = None
 
-@dataclass
-class VolumeMountDO(BaseDO):
+class VolumeMountDO(BaseModel):
     name: str
     mount_path: str
     read_only: Optional[bool]=None
     sub_path: Optional[str]=None
 
-@dataclass
-class ContainerPortDO(BaseDO):
+class ContainerPortDO(BaseModel):
     port: int
     name: Optional[str] = None
     protocol: Optional[str] = None
     host_ip: Optional[str] = None
     host_port: Optional[int] = None
 
-@dataclass
-class HTTPGetActionDO(BaseDO):
+class HTTPGetActionDO(BaseModel):
     port: int
     host: Optional[str] = None
     path: Optional[str] = None
     http_headers: Optional[List[Dict]] = None
     scheme: Optional[str] = None
 
-@dataclass
-class TCPSocketActionDO(BaseDO):
+class TCPSocketActionDO(BaseModel):
     port: int
     host: Optional[str] = None
 
-@dataclass
-class GRPCActionDO(BaseDO):
+class GRPCActionDO(BaseModel):
     port: int
     service: Optional[str] = None
 
-@dataclass
-class ProbeDO(BaseDO):
+class ProbeDO(BaseModel):
     initial_delay_seconds: int = 10
     period_seconds: int = 10
     success_threshold: Optional[int] = None
@@ -368,25 +350,21 @@ class ProbeDO(BaseDO):
     http_get: Optional[HTTPGetActionDO] = None
     tcp_socket: Optional[TCPSocketActionDO] = None
 
-@dataclass
-class LabelSelectorRequirementDO(BaseDO):
+class LabelSelectorRequirementDO(BaseModel):
     key: str
     operator: str
     values: Optional[List[str]] = None
 
-@dataclass
-class LabelSelectorDO(BaseDO):
+class LabelSelectorDO(BaseModel):
     match_expressions: Optional[List[LabelSelectorRequirementDO]] = None
     match_labels: Optional[Dict] = None
 
-@dataclass
-class SecurityContextDO(BaseDO):
+class SecurityContextDO(BaseModel):
     privileged: Optional[bool]=None
     run_as_user: Optional[int]=None
     run_as_non_root: Optional[bool]=None
 
-@dataclass
-class ContainerSettingDO(BaseDO):
+class ContainerSettingDO(BaseModel):
     container_name: str
     container_image: str
     command: Optional[List[str]] = None
@@ -402,8 +380,7 @@ class ContainerSettingDO(BaseDO):
     liveness_probe: Optional[ProbeDO] = None
     ports: Optional[List[ContainerPortDO]] = None
 
-@dataclass
-class JobSettingDO(BaseDO):
+class JobSettingDO(BaseModel):
     job_name: str
     namespace_name: str
     labels: Dict
